web/request.py
branchstable
changeset 8238 087bb529035c
parent 8177 e4ab883f07d9
child 8239 c6cdd060212e
--- a/web/request.py	Mon Feb 13 17:57:07 2012 +0100
+++ b/web/request.py	Thu Feb 16 14:14:52 2012 +0100
@@ -63,7 +63,7 @@
     * if the parameter is already a list or tuple, just skip internal
       markers
 
-    if pop is True, the parameter is removed from the form dictionnary
+    if pop is True, the parameter is removed from the form dictionary
     """
     if pop:
         try:
@@ -97,7 +97,7 @@
         self.html_headers = HTMLHead(self)
         # form parameters
         self.setup_params(form)
         # dictionnary that may be used to store request data that has to be
         # shared among various components used to publish the request (views,
         # controller, application...)
         self.data = {}
@@ -253,7 +253,7 @@
         * if the parameter is already a list or tuple, just skip internal
           markers
 
-        if pop is True, the parameter is removed from the form dictionnary
+        if pop is True, the parameter is removed from the form dictionary
         """
         if form is None:
             form = self.form
@@ -97,7 +97,7 @@
         # form parameters
         self.setup_params(form)
-        # dictionnary that may be used to store request data that has to be
+        # dictionary that may be used to store request data that has to be
         # shared among various components used to publish the request (views,
         # controller, application...)